@@ -95,14 +95,9 @@ void StopWatch::CalcSize()
 
 Lum::OS::Font* StopWatch::FindFont()
 {
-  Lum::OS::FontRef font;
-  bool             fits;
-  size_t           fontSize;
+  size_t fontSize=height;
 
-  font=minFont;
-  fontSize=font->pixelHeight+1;
-
-  do {
+  while (true) {
     Lum::OS::FontRef tmpFont;
     size_t           w=0,h=0;
 
@@ -121,17 +116,14 @@ Lum::OS::Font* StopWatch::FindFont()
       tmpFont->StringExtent(L":",extent,Lum::OS::Font::bold);
       h=std::max(h,extent.height);
 
-      fits=(4*w+extent.width<=width && h<=height);
-
-      if (fits) {
-        font=tmpFont;
-        fontSize++;
+      if (4*w+extent.width<=width && h<=height) {
+        return tmpFont;
       }
     }
-    else {
-      fits=(fontSize<=height);
-    }
-  } while (fits);
+
+    fontSize--;
+
+  };
 
   return font.Get();
 }
